==> jc-1.4.0.tar.gz: java/awt/image/ByteLookupTable.h <==
// public class java.awt.image.ByteLookupTable

// class file dependencies
// @dep_class 8fc12a94fdc9e33 java_awt_image_ByteLookupTable
// @dep_class a552b3bb67ab409f java_awt_image_LookupTable
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_image_LookupTable

#include "java/awt/image/LookupTable.h"

#ifndef _JC_java_awt_image_ByteLookupTable_H_
#define _JC_java_awt_image_ByteLookupTable_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_image_ByteLookupTable$sub_refs	_jc_java_awt_image_ByteLookupTable$sub_refs;
typedef struct _jc_java_awt_image_ByteLookupTable$sub_nonrefs	_jc_java_awt_image_ByteLookupTable$sub_nonrefs;
typedef struct _jc_java_awt_image_ByteLookupTable$refs	_jc_java_awt_image_ByteLookupTable$refs;
typedef struct _jc_java_awt_image_ByteLookupTable$nonrefs	_jc_java_awt_image_ByteLookupTable$nonrefs;
typedef struct _jc_java_awt_image_ByteLookupTable$object	_jc_java_awt_image_ByteLookupTable$object;

typedef const struct _jc_java_awt_image_ByteLookupTable$vmethods	_jc_java_awt_image_ByteLookupTable$vmethods;
typedef const struct _jc_java_awt_image_ByteLookupTable$vtable	_jc_java_awt_image_ByteLookupTable$vtable;
typedef const struct _jc_java_awt_image_ByteLookupTable$vtype	_jc_java_awt_image_ByteLookupTable$vtype;

// Constructors
extern void _jc_java_awt_image_ByteLookupTable$method$_init$85a20918701c98c3(_jc_env *, struct _jc_java_awt_image_ByteLookupTable$object *, jint, struct _jc_byte_array *);
extern void _jc_java_awt_image_ByteLookupTable$method$_init$bf8695c29f90508d(_jc_env *, struct _jc_java_awt_image_ByteLookupTable$object *, jint, struct _jc_object_array *);

// Virtual methods
extern _jc_object_array *_jc_java_awt_image_ByteLookupTable$method$getTable$b9430d15461e63c4(_jc_env *, struct _jc_java_awt_image_ByteLookupTable$object *);
extern _jc_byte_array *_jc_java_awt_image_ByteLookupTable$method$lookupPixel$c6c4d17d3e5910e7(_jc_env *, struct _jc_java_awt_image_ByteLookupTable$object *, struct _jc_byte_array *, struct _jc_byte_array *);
extern _jc_int_array *_jc_java_awt_image_ByteLookupTable$method$lookupPixel$0f1f0c9450fe78a3(_jc_env *, struct _jc_java_awt_image_ByteLookupTable$object *, struct _jc_int_array *, struct _jc_int_array *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_ByteLookupTable$method_info$getTable$b9430d15461e63c4;
extern _jc_method _jc_java_awt_image_ByteLookupTable$method_info$lookupPixel$c6c4d17d3e5910e7;
extern _jc_method _jc_java_awt_image_ByteLookupTable$method_info$lookupPixel$0f1f0c9450fe78a3;

// Virtual methods structure
struct _jc_java_awt_image_ByteLookupTable$vmethods {
	_jc_object_array	*(*getTable$b9430d15461e63c4)(_jc_env *, struct _jc_java_awt_image_ByteLookupTable$object *);
	_jc_byte_array	*(*lookupPixel$c6c4d17d3e5910e7)(_jc_env *, struct _jc_java_awt_image_ByteLookupTable$object *, struct _jc_byte_array *, struct _jc_byte_array *);
	_jc_int_array	*(*lookupPixel$0f1f0c9450fe78a3)(_jc_env *, struct _jc_java_awt_image_ByteLookupTable$object *, struct _jc_int_array *, struct _jc_int_array *);
};

// Vtable
struct _jc_java_awt_image_ByteLookupTable$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_LookupTable$vmethods	java_awt_image_LookupTable;
	_jc_java_awt_image_ByteLookupTable$vmethods	java_awt_image_ByteLookupTable;
};

// Vtype
struct _jc_java_awt_image_ByteLookupTable$vtype {
	_jc_type			type;
	_jc_java_awt_image_ByteLookupTable$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_ByteLookupTable$sub_refs {
	_jc_object_array	*data;
};

// Reference instance fields (object)
struct _jc_java_awt_image_ByteLookupTable$refs {
    _jc_java_awt_image_ByteLookupTable$sub_refs	java_awt_image_ByteLookupTable;
    _jc_java_awt_image_LookupTable$sub_refs	java_awt_image_LookupTable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_ByteLookupTable$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_ByteLookupTable$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_LookupTable$sub_nonrefs	java_awt_image_LookupTable;
    _jc_java_awt_image_ByteLookupTable$sub_nonrefs	java_awt_image_ByteLookupTable;
};

// Object instance structure
struct _jc_java_awt_image_ByteLookupTable$object {
	_jc_java_awt_image_ByteLookupTable$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_ByteLookupTable$vtype	*vtype;
	_jc_java_awt_image_ByteLookupTable$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_ByteLookupTable$vtype _jc_java_awt_image_ByteLookupTable$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_ByteLookupTable, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_ByteLookupTable$class_object;

#endif	/* _JC_java_awt_image_ByteLookupTable_H_ */

==> jc-1.4.6.tar.gz: java/awt/image/ByteLookupTable.h <==
// public class java.awt.image.ByteLookupTable

// class file dependencies
// @dep_class 8fc12a94fdc9e33 java_awt_image_ByteLookupTable
// @dep_class a552b3bb67ab409f java_awt_image_LookupTable
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_image_LookupTable

#include "java/awt/image/LookupTable.h"

#ifndef _JC_java_awt_image_ByteLookupTable_H_
#define _JC_java_awt_image_ByteLookupTable_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_image_ByteLookupTable$sub_refs	_jc_java_awt_image_ByteLookupTable$sub_refs;
typedef struct _jc_java_awt_image_ByteLookupTable$sub_nonrefs	_jc_java_awt_image_ByteLookupTable$sub_nonrefs;
typedef struct _jc_java_awt_image_ByteLookupTable$refs	_jc_java_awt_image_ByteLookupTable$refs;
typedef struct _jc_java_awt_image_ByteLookupTable$nonrefs	_jc_java_awt_image_ByteLookupTable$nonrefs;
typedef struct _jc_java_awt_image_ByteLookupTable$object	_jc_java_awt_image_ByteLookupTable$object;

typedef const struct _jc_java_awt_image_ByteLookupTable$vmethods	_jc_java_awt_image_ByteLookupTable$vmethods;
typedef const struct _jc_java_awt_image_ByteLookupTable$vtable	_jc_java_awt_image_ByteLookupTable$vtable;
typedef const struct _jc_java_awt_image_ByteLookupTable$vtype	_jc_java_awt_image_ByteLookupTable$vtype;

// Constructors
extern void _jc_java_awt_image_ByteLookupTable$method$_init$85a20918701c98c3(_jc_env *, struct _jc_java_awt_image_ByteLookupTable$object *, jint, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_ByteLookupTable$method$_init$bf8695c29f90508d(_jc_env *, struct _jc_java_awt_image_ByteLookupTable$object *, jint, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_java_awt_image_ByteLookupTable$method$getTable$b9430d15461e63c4(_jc_env *, struct _jc_java_awt_image_ByteLookupTable$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_java_awt_image_ByteLookupTable$method$lookupPixel$c6c4d17d3e5910e7(_jc_env *, struct _jc_java_awt_image_ByteLookupTable$object *, struct _jc_byte_array *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern _jc_int_array *_jc_java_awt_image_ByteLookupTable$method$lookupPixel$0f1f0c9450fe78a3(_jc_env *, struct _jc_java_awt_image_ByteLookupTable$object *, struct _jc_int_array *, struct _jc_int_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_ByteLookupTable$method_info$getTable$b9430d15461e63c4;
extern _jc_method _jc_java_awt_image_ByteLookupTable$method_info$lookupPixel$c6c4d17d3e5910e7;
extern _jc_method _jc_java_awt_image_ByteLookupTable$method_info$lookupPixel$0f1f0c9450fe78a3;

// Virtual methods structure
struct _jc_java_awt_image_ByteLookupTable$vmethods {
	_jc_object_array	*(*getTable$b9430d15461e63c4)(_jc_env *, struct _jc_java_awt_image_ByteLookupTable$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*lookupPixel$c6c4d17d3e5910e7)(_jc_env *, struct _jc_java_awt_image_ByteLookupTable$object *, struct _jc_byte_array *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	_jc_int_array	*(*lookupPixel$0f1f0c9450fe78a3)(_jc_env *, struct _jc_java_awt_image_ByteLookupTable$object *, struct _jc_int_array *, struct _jc_int_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_image_ByteLookupTable$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_LookupTable$vmethods	java_awt_image_LookupTable;
	_jc_java_awt_image_ByteLookupTable$vmethods	java_awt_image_ByteLookupTable;
};

// Vtype
struct _jc_java_awt_image_ByteLookupTable$vtype {
	_jc_type			type;
	_jc_java_awt_image_ByteLookupTable$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_ByteLookupTable$sub_refs {
	_jc_object_array	*data;
};

// Reference instance fields (object)
struct _jc_java_awt_image_ByteLookupTable$refs {
    _jc_java_awt_image_ByteLookupTable$sub_refs	java_awt_image_ByteLookupTable;
    _jc_java_awt_image_LookupTable$sub_refs	java_awt_image_LookupTable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_ByteLookupTable$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_ByteLookupTable$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_LookupTable$sub_nonrefs	java_awt_image_LookupTable;
    _jc_java_awt_image_ByteLookupTable$sub_nonrefs	java_awt_image_ByteLookupTable;
};

// Object instance structure
struct _jc_java_awt_image_ByteLookupTable$object {
	_jc_java_awt_image_ByteLookupTable$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_ByteLookupTable$vtype	*vtype;
	_jc_java_awt_image_ByteLookupTable$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_ByteLookupTable$vtype _jc_java_awt_image_ByteLookupTable$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_ByteLookupTable, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_ByteLookupTable$class_object;

#endif	/* _JC_java_awt_image_ByteLookupTable_H_ */
